prove_stacked_opening_reduction_gpu

Function prove_stacked_opening_reduction_gpu 

pub fn prove_stacked_opening_reduction_gpu<HS, TS>(
    device: &GpuDevice,
    transcript: &mut TS,
    mpk: &DeviceMultiStarkProvingKey<GenericGpuBackend<HS>>,
    ctx: ProvingContext<GenericGpuBackend<HS>>,
    common_main_pcs_data: StackedPcsDataGpu<F, HS::Digest>,
    r: &[EF],
) -> Result<(StackingProof<HS::SC>, Vec<EF>, Vec<StackedPcsData2<HS::Digest>>), StackedReductionError>
Batch sumcheck to reduce trace openings, including rotations, to stacked matrix opening.

The stacked_matrix, stacked_layout should be the result of stacking the traces with parameters l_skip and n_stack.