pub struct StackedPcsData2<D = Digest> { /* private fields */ }Expand description
A struct for holding stacked pcs data. We only need the MerkleTreeGpu from StackedPcsDataGpu
but we wrap the latter in an Arc to provide uniformity in dealing with common main and
preprocessed/cached traces. This struct stores the unstacked traces, in prismalinear
evaluation form, corresponding to the stacked pcs data.
Generic over the Merkle digest type D. The default D = Digest preserves the existing
BabyBear-Poseidon2 behaviour.
Implementations
Sourceimpl<D> StackedPcsData2<D>
impl<D> StackedPcsData2<D>
Sourcepub unsafe fn from_raw(
pcs_data: Arc<StackedPcsDataGpu<F, D>>,
traces: Vec<DeviceMatrix<F>>,
) -> Self
pub unsafe fn from_raw( pcs_data: Arc<StackedPcsDataGpu<F, D>>, traces: Vec<DeviceMatrix<F>>, ) -> Self
Safety
traces must be the traces that were committed to in pcs_data.
pub fn layout(&self) -> &StackedLayout